==> kwap-msg-0.2.5.crate: kwap-msg-0.2.5/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.2.5 (2021-12-30)


### Bug Fixes

* **msg:** make Code::new a const fn ([#29](https://github.com/clov-coffee/kwap/issues/29)) ([e0f22cf](https://github.com/clov-coffee/kwap/commit/e0f22cf0663b9ba7a4617f3fa4efbaf82856d155))

### 0.2.4 (2021-12-30)


### Features

* **msg:** add Code::new ([#28](https://github.com/clov-coffee/kwap/issues/28)) ([47c1ce7](https://github.com/clov-coffee/kwap/commit/47c1ce7c0867052aec9ddba041335a2b763202c4))

### 0.2.3 (2021-12-30)

### 0.2.2 (2021-12-30)

### 0.2.1 (2021-12-30)

## 0.2.0 (2021-12-29)


### ⚠ BREAKING CHANGES

* combine no_alloc and alloc into one Message generic over collection (#17)

### Features

* combine no_alloc and alloc into one Message generic over collection ([#17](https://github.com/clov-coffee/kwap/issues/17)) ([10939a2](https://github.com/clov-coffee/kwap/commit/10939a230751183e49b60adb45d0bfa84d28a202))

### 0.1.6 (2021-12-27)

### 0.1.5 (2021-12-27)


### Bug Fixes

* bump amend ([c6e34cb](https://github.com/clov-coffee/kwap/commit/c6e34cbe57c52bf6c888ef856a4c9ff43d4ccd23))

### 0.1.4 (2021-12-26)


### Bug Fixes

* update token to store token bytes verbatim  ([#8](https://github.com/clov-coffee/kwap/issues/8)) ([9dc6724](https://github.com/clov-coffee/kwap/commit/9dc6724d9bbc1ef6f7c81156f879ffec88cba20f))

### 0.1.3 (2021-12-26)

### 0.1.2 (2021-12-26)

### 0.1.1 (2021-12-26)

==> kwap-msg-0.2.7.crate: kwap-msg-0.2.7/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.2.7 (2022-01-01)


### Bug Fixes

* **msg:** update kwap_common ([#37](https://github.com/clov-coffee/kwap/issues/37)) ([73baf95](https://github.com/clov-coffee/kwap/commit/73baf95ae05faded1751aa4e7e849c62df0ade6b))

### 0.2.6 (2021-12-31)

### 0.2.5 (2021-12-30)


### Bug Fixes

* **msg:** make Code::new a const fn ([#29](https://github.com/clov-coffee/kwap/issues/29)) ([e0f22cf](https://github.com/clov-coffee/kwap/commit/e0f22cf0663b9ba7a4617f3fa4efbaf82856d155))

### 0.2.4 (2021-12-30)


### Features

* **msg:** add Code::new ([#28](https://github.com/clov-coffee/kwap/issues/28)) ([47c1ce7](https://github.com/clov-coffee/kwap/commit/47c1ce7c0867052aec9ddba041335a2b763202c4))

### 0.2.3 (2021-12-30)

### 0.2.2 (2021-12-30)

### 0.2.1 (2021-12-30)

## 0.2.0 (2021-12-29)


### ⚠ BREAKING CHANGES

* combine no_alloc and alloc into one Message generic over collection (#17)

### Features

* combine no_alloc and alloc into one Message generic over collection ([#17](https://github.com/clov-coffee/kwap/issues/17)) ([10939a2](https://github.com/clov-coffee/kwap/commit/10939a230751183e49b60adb45d0bfa84d28a202))

### 0.1.6 (2021-12-27)

### 0.1.5 (2021-12-27)


### Bug Fixes

* bump amend ([c6e34cb](https://github.com/clov-coffee/kwap/commit/c6e34cbe57c52bf6c888ef856a4c9ff43d4ccd23))

### 0.1.4 (2021-12-26)


### Bug Fixes

* update token to store token bytes verbatim  ([#8](https://github.com/clov-coffee/kwap/issues/8)) ([9dc6724](https://github.com/clov-coffee/kwap/commit/9dc6724d9bbc1ef6f7c81156f879ffec88cba20f))

### 0.1.3 (2021-12-26)

### 0.1.2 (2021-12-26)

### 0.1.1 (2021-12-26)
